@@ -139,7 +139,7 @@ def create_grid_layout(rowNum=8, colNum=12, row_labels=None, col_labels=None,
     set_tick_lines_visibility(ax_main, False)
     set_tick_labels_visibility(ax_main, False)
 
-    # Configure subplot apperance
+    # Configure subplot appearance
     subplot_kw.update(xlim=xlim, ylim=ylim, xscale=xscale, yscale=yscale) # This could potentially confuse a user
 
     plt.subplots_adjust(wspace=wspace, hspace=hspace)
@@ -204,7 +204,6 @@ def create_grid_layout(rowNum=8, colNum=12, row_labels=None, col_labels=None,
                 if hide_tick_labels:
                     set_tick_labels_visibility(ax, False)
 
-
             if plotFuncList is not None:
                 for plot_function in plotFuncList:
                     plot_function(row, col)
@@ -213,6 +212,7 @@ def create_grid_layout(rowNum=8, colNum=12, row_labels=None, col_labels=None,
 
     return (ax_main, ax_subplots)
 
+
 def autoscale_subplots(subplots=None, axis='both'):
     """
     Sets the x and y axis limits for each subplot to match the x and y axis
@@ -259,11 +259,43 @@ def autoscale_subplots(subplots=None, axis='both'):
         if axis in ('y', 'both', 'xy', 'yx'):
             ax.set_ylim((ymin, ymax))
 
+def scale_subplots(subplots=None, xlim='auto', ylim='auto'):
+    """
+    Sets the x and y axis limits for a collection of subplots.
+
+    Parameters
+    -----------
+    subplots : ndarray or list of matplotlib.axes.Axes
+
+    xlim : None | 'auto' | (xmin, xmax)
+        'auto' : sets the limits according to the most
+        extreme values of data encountered.
+    ylim : None | 'auto' | (ymin, ymax)
+
+    Returns
+    -------------
+    None
+    """
+    auto_axis = ''
+    if xlim == 'auto':
+        auto_axis += 'x'
+    if ylim == 'auto':
+        auto_axis += 'y'
+
+    autoscale_subplots(subplots, auto_axis)
+
+    for loc, ax in numpy.ndenumerate(subplots):
+        if 'x' not in auto_axis:
+            ax.set_xlim(xlim)
+        if 'y' not in auto_axis:
+            ax.set_ylim(ylim)
+
 @doc_replacer
 def plot_ndpanel(panel, func=None,
                    xlim='auto', ylim='auto',
                    row_labels='auto', col_labels='auto',
                    row_name='auto', col_name='auto',
+                   pass_slicing_meta_to_func=False,
                    subplot_xlabel=None, subplot_ylabel=None,
                    row_name_pad=40.0, col_name_pad=40.0,
                    hspace=0, wspace=0,
@@ -285,6 +317,12 @@ def plot_ndpanel(panel, func=None,
         minor : cols
     func : function that accepts a slice of a panel (two dimensions less than input panel)
     {_graph_grid_layout}
+
+    pass_slicing_meta_to_func : [False | True]
+        Changes the arguments that are passed to the provided function.
+        If False: func(data_slice, **kwargs) (Default)
+        If True: func(data_slice, row=row, col=col, row_value=row_value, col_value=col_value, **kwargs)
+
     grid_kwargs : dict
         kwargs to be passed to the create_grid_layout method. See its documentation for further details.
     legend : None, tuple
@@ -362,7 +400,11 @@ def plot_ndpanel(panel, func=None,
         data_slice = panel.iloc[row].iloc[col]
         row_value = panel.axes[0][row]
         col_value = panel.axes[1][col]
-        func(data_slice, row=row, col=col, row_value=row_value, col_value=col_value, **kwargs)
+
+        if pass_slicing_meta_to_func:
+            func(data_slice, row=row, col=col, row_value=row_value, col_value=col_value, **kwargs)
+        else:
+            func(data_slice, **kwargs)
 
     autoscale_subplots(ax_subplots, axis)
 
@@ -433,7 +475,7 @@ def plot_ndpanel_1d(data, plot_func=None, ylabel=None, axes_num=0, ax_list=None,
     ----------
     ax_list = subplots(2, 5, figsize=(14, 14))[1].flatten()
     subplots_adjust(wspace=0.4, hspace=0.4)
-    plot_group(data, ylabel='OD (600 nm)', title='value', ax_list=ax_list, legend_title='legend title')
+    plot_ndpanel_1d(data, ylabel='OD (600 nm)', title='value', ax_list=ax_list, legend_title='legend title')
     """
     num_dim = len(data.axes[axes_num])
     axes_name = data.axes[axes_num].name
@@ -512,6 +554,8 @@ def plot_heat_map(z, include_values=False,
         Flips the data along the y axis if true
     convert_to_log_scale : bool
         If true, plots the log of z.
+    clabel_pos : 'top' | 'bottom'
+        Location of the column labels. Default is 'top'.
     cmap : colormap | str
         colormap to use for plotting the values; e.g., matplotlib.cmap.Blues,
         if str then expecting something like 'Blues' to look up using getattr(matplotlib.cm, ...)
@@ -696,27 +740,52 @@ def plot_table(matrix, text_format='{:.2f}', cmap=None, **kwargs):
 #### PLOTTING VECTOR FIELDS ####
 ################################
 
-def plot_arrow_path(xposList, yposList, head_width=0.03, head_length=0.03, **args):
+from matplotlib.patches import ConnectionPatch
+
+def plot_arrow_path(x_coordinates, y_coordinates, arrowstyle="fancy",  **kwargs):
     """
-    Draws a path of arrows
-    -> xposList is a list of x positions
-    -> yposlist is a list of y positions
-    -> **args is a dictionary of arguments for the plt.arrow function
+    Draws a path of arrows following the path of the coordinates.
+
+    Note: This is just a wrapper around matplotlib's ConnectionPath, which at the moment does not add much functionality.
+
+    Parameters
+    ------------------
+    x_coordinates : ndarray or list
+        X coordinates
+    y_coordinates : ndarray or list
+        Y coordinates
+    arrowstyle : str
+        'fancy', '->', look up other ones on matplotlib's page.
+    kwargs : keyword arguments passed to ConnectionPath
+
+    Returns
+    ---------------
+
+    list
+        arrow patches added
+
+    Example
+    ---------------
+
+    x = [1, 2, 5, 1]
+    y = [0, 3, 1, 2]
+
+    graph.plot_arrow_path(x, y, arrowstyle='fancy', color=color, alpha=0.5, shrinkA=2, shrinkB=4);
+
+    xlim(0, 5) # it's necessary to set limits, not autorelimiting after using this function!
+    ylim(0, 5)
     """
-    positionList = zip(xposList, yposList)
+    position_list = zip(x_coordinates, y_coordinates)
+    ax = kwargs.pop('ax', pl.gca())
 
-    for index in range(len(positionList)-1):
-        initialPoint = positionList[index]
-        finalPoint = positionList[index+1]
-        dx, dy = (finalPoint[0] - initialPoint[0], finalPoint[1] - initialPoint[1])
-        dMove = (dx, dy)
-        intermediatePoint = (initialPoint[0]+dx/2.0, initialPoint[1]+ dy/2.0)
+    patch_list = []
 
-        arrowOneDirection = (initialPoint[0], initialPoint[1], dx/2.0, dy/2.0)
-        arrowTwoDirection = (initialPoint[0] + dx/2.0, initialPoint[1] + dy/2.0, dx/2.0, dy/2.0)
-
-        plt.arrow(*arrowOneDirection, head_width=head_width, head_length=head_length, head_starts_at_zero=False, **args)
-        plt.arrow(*arrowTwoDirection, head_width=0.00, head_length=0.00, **args)
+    for index in range(len(position_list)-1):
+        con = ConnectionPatch(xyA=position_list[index], xyB=position_list[index+1], coordsA="data", coordsB="data",
+                              axesA=ax, axesB=ax, arrowstyle=arrowstyle, **kwargs)
+        patch_list.append(con)
+        ax.add_artist(con)
+    return patch_list
 
 ###############################
 ## BEAUTIFICATION OF PLOTS ####
@@ -958,7 +1027,7 @@ def get_slice(panel, row, col):
 if __name__ == '__main__':
     print plot_ndpanel.__doc__
     example = None
-    #example = 'Example 2'
+    example = 'Example 2'
     if example == 'Example 1':
         # Example using arrow path
         a = numpy.random.random((1,10)).flatten()
@@ -967,15 +1036,18 @@ if __name__ == '__main__':
         plot_arrow_path(a,b, fc=['r', 'b', 'm'][0], ec='gray', alpha=0.5)
         plt.show()
     elif example == 'Example 2':
-        handles = create_grid_layout(2, 3, wspace=0.3, row_labels=['1', '2', '3', '4', '5'], col_labels = ['1', '2', '3', '4', '4'], hide_tick_lines=True)
+        handles = create_grid_layout(2, 3, wspace=0.3, hspace=0.1,
+                row_labels=['1', '2', '3', '4', '5'], col_labels = ['1', '2', '3', '4', '4'],
+                hide_tick_lines=False,
+                xlim=(-500, 500), ylim=(-500, 500))
 
         for loc, ax in numpy.ndenumerate(handles[1]):
             a = numpy.random.random((1,10)).flatten() * 100
             b = numpy.random.random((1,10)).flatten() * 100
             if loc != (0, 0):
                 ax.plot(a, b)
-        #plt.autoscale(True, 'both', True)
-        autoscale_subplots(handles[1])
+        #plt.autoscale(True, '', True)
+        #autoscale_subplots(handles[1], 'both')
         plt.show()
     elif example == 'Example 3':
         a = numpy.random.random((10,10))
